@@ -118,7 +118,8 @@ class LaunchpadOAuthAwareHttp(RestfulHttp):
         """Helper method to detect an error caused by a bad OAuth token."""
         return (response.status == 401 and
                 (content.startswith("Expired token")
-                 or content.startswith("Invalid token")))
+                 or content.startswith("Invalid token")
+                 or content.startswith("Unknown access token")))
 
     def _request(self, *args):
         response, content = super(
